package net.knarcraft.blacksmith.listener;

import net.citizensnpcs.api.event.NPCRightClickEvent;
import net.knarcraft.blacksmith.BlacksmithPlugin;
import net.knarcraft.blacksmith.formatting.BlacksmithTranslatableMessage;
import net.knarcraft.blacksmith.trait.BlacksmithTrait;
import net.knarcraft.blacksmith.trait.CustomTrait;
import net.knarcraft.blacksmith.trait.ScrapperTrait;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.logging.Level;

/**
 * A listener for detecting and handling a Blacksmith being right-clicked
 */
public class NPCClickListener implements Listener {

    @EventHandler
    public void onRightClick(@NotNull NPCRightClickEvent event) {
        //We only care about blacksmiths
        if (event.getNPC().hasTrait(BlacksmithTrait.class)) {
            handleNPCClick(event, event.getNPC().getTraitNullable(BlacksmithTrait.class));
        } else if (event.getNPC().hasTrait(ScrapperTrait.class)) {
            handleNPCClick(event, event.getNPC().getTraitNullable(ScrapperTrait.class));
        }
    }

    /**
     * Handles a player clicking on a blacksmith or a scrapper NPC
     *
     * @param event       <p>The NPC click event performed</p>
     * @param customTrait <p>The NPC's custom trait</p>
     */
    private void handleNPCClick(@NotNull NPCRightClickEvent event, @Nullable CustomTrait<?> customTrait) {
        if (customTrait == null) {
            BlacksmithPlugin.getInstance().getLogger().log(Level.WARNING, "Could not get trait from NPC!");
            return;
        }

        //Perform any necessary pre-session work
        Player player = event.getClicker();

        //Permission check
        if (!player.hasPermission("blacksmith.use")) {
            BlacksmithPlugin.getStringFormatter().displayErrorMessage(player,
                    BlacksmithTranslatableMessage.PERMISSION_DENIED);
            return;
        }

        if (!customTrait.prepareForSession(player)) {
            return;
        }

        if (customTrait.hasSession()) {
            //Continue the existing session
            customTrait.continueSession(player);
        } else {
            //Start a new session
            customTrait.startSession(player);
        }
    }

}
